summaryrefslogtreecommitdiff
path: root/gui/AboutDlg.c
diff options
context:
space:
mode:
authorSND\dario86_cp <SND\dario86_cp@e17a0e51-4ae3-4d35-97c3-1a29b211df97>2012-02-19 02:15:18 +0000
committerSND\dario86_cp <SND\dario86_cp@e17a0e51-4ae3-4d35-97c3-1a29b211df97>2012-02-19 02:15:18 +0000
commit79c267cda79b52cff2ce83397af87aac64d049d7 (patch)
tree43f49fa80e13ee9303d5472f0176c5062fc2e5dc /gui/AboutDlg.c
parent12ddb091ed0a98ef323f2ee9e743386f570a4325 (diff)
downloadpcsxr-79c267cda79b52cff2ce83397af87aac64d049d7.tar.gz
Updated Free Software Foundation address (Jem256).
git-svn-id: https://pcsxr.svn.codeplex.com/svn/pcsxr@75156 e17a0e51-4ae3-4d35-97c3-1a29b211df97
Diffstat (limited to 'gui/AboutDlg.c')
-rw-r--r--gui/AboutDlg.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/gui/AboutDlg.c b/gui/AboutDlg.c
index 380b8e61..dec82daf 100644
--- a/gui/AboutDlg.c
+++ b/gui/AboutDlg.c
@@ -13,7 +13,7 @@
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307 USA
*/
#include "Linux.h"
@@ -85,7 +85,7 @@ void RunAboutDialog(void) {
"\n"
"You should have received a copy of the GNU General Public License "
"along with this program; if not, write to the Free Software "
- "Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307 USA.");
+ "Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.");
AboutDlg = gtk_about_dialog_new();
gtk_about_dialog_set_program_name(GTK_ABOUT_DIALOG(AboutDlg), "PCSX-Reloaded");
@@ -13,7 +13,7 @@
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
*/
#include "Linux.h"